.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/
.. _Icomoon: http://icomoon.io/

==============
Django Icomoon
==============

A `Django`_ app to deploy downloaded webfonts from `Icomoon`_ and display
them into a gallery.


Dependencies
************

* `Python`_>=3.8;
* `Django`_>=3.2;


Links
*****

* Read the documentation on `Read the docs <https://django-icomoon.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/django-icomoon>`_;
* Clone it on its `Github repository <https://github.com/sveetch/django-icomoon>`_;
